
### MagCore简介

MagCore 这是一款多玩家对战游戏。

使用Python来制作MagCore游戏客户端，通过控制战斗逻辑来取得胜利。

目的是通过游戏帮助零基础同学，从零学Python，在游戏中体验编程的乐趣。

无论是「新手」亦或是「骨灰」级程序员，MagCore都适合你，你需要通过不断地优化游戏攻击算法逻辑来使自己处于不败之地。

来吧~加入程序员的战争！

### pymagcore模块

pymagcore模块中封装了MagCore游戏API接口，利用pymagcore模块可直接调用游戏API，来完成创建玩家、创建游戏房间、执行攻击等动作。

直接通过pip安装即可

```
python -m pip install pymagcore
```
